WHAT NEW IN X10.28 WED

X 上的 AI 合集档案 · 22 个合集 · 58,924 条

jevPOST

用 Jev 替换提示词分类器

作者把提示词追踪分类器换成 Jev,单次耗时从 1765 秒降到 6.3 秒,成本从 0.944 美元降到 0.002 美元。

Mitch Malone
@mitchmalone2026.09.23收录原推发布于 2026.09.22
Mitch Malone @mitchmalone原推发布于 2026.09.22
在 X 上打开原推

Last night I replaced our prompt tracking classifier with Jev. Time saving / run: 1,765s down to 6.3s Cost saving / run: $0.944 -> $0.002

x.com/mitchmalone/status/2102174351504388384采集于 2026.09.23 10:32